==> kubernetes-model-autoscaling-5.1.1-sources.jar: annotations/io/fabric8/kubernetes/api/model/autoscaling/v2beta2/CrossVersionObjectReferenceBuilder.java <==
package io.fabric8.kubernetes.api.model.autoscaling.v2beta2;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class CrossVersionObjectReferenceBuilder extends io.fabric8.kubernetes.api.model.autoscaling.v2beta2.CrossVersionObjectReferenceFluentImpl<io.fabric8.kubernetes.api.model.autoscaling.v2beta2.CrossVersionObjectReferenceBuilder> implements VisitableBuilder<io.fabric8.kubernetes.api.model.autoscaling.v2beta2.CrossVersionObjectReference,io.fabric8.kubernetes.api.model.autoscaling.v2beta2.CrossVersionObjectReferenceBuilder> {

    io.fabric8.kubernetes.api.model.autoscaling.v2beta2.CrossVersionObjectReferenceFluent<?> fluent;
    Boolean validationEnabled;

    public CrossVersionObjectReferenceBuilder() {
        this(true);
    }

    public CrossVersionObjectReferenceBuilder(Boolean validationEnabled) {
        this(new CrossVersionObjectReference(), validationEnabled);
    }

    public CrossVersionObjectReferenceBuilder(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.CrossVersionObjectReferenceFluent<?> fluent) {
        this(fluent, true);
    }

    public CrossVersionObjectReferenceBuilder(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.CrossVersionObjectReferenceFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new CrossVersionObjectReference(), validationEnabled);
    }

    public CrossVersionObjectReferenceBuilder(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.CrossVersionObjectReferenceFluent<?> fluent,io.fabric8.kubernetes.api.model.autoscaling.v2beta2.CrossVersionObjectReference instance) {
        this(fluent, instance, true);
    }

    public CrossVersionObjectReferenceBuilder(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.CrossVersionObjectReferenceFluent<?> fluent,io.fabric8.kubernetes.api.model.autoscaling.v2beta2.CrossVersionObjectReference instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withApiVersion(instance.getApiVersion()); 
        fluent.withKind(instance.getKind()); 
        fluent.withName(instance.getName()); 
        this.validationEnabled = validationEnabled; 
    }

    public CrossVersionObjectReferenceBuilder(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.CrossVersionObjectReference instance) {
        this(instance,true);
    }

    public CrossVersionObjectReferenceBuilder(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.CrossVersionObjectReference instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withApiVersion(instance.getApiVersion()); 
        this.withKind(instance.getKind()); 
        this.withName(instance.getName()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.CrossVersionObjectReference build() {
        CrossVersionObjectReference buildable = new CrossVersionObjectReference(fluent.getApiVersion(),fluent.getKind(),fluent.getName());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        CrossVersionObjectReferenceBuilder that = (CrossVersionObjectReferenceBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}

==> kubernetes-model-autoscaling-5.3.1-sources.jar: annotations/io/fabric8/kubernetes/api/model/autoscaling/v2beta2/CrossVersionObjectReferenceBuilder.java <==
package io.fabric8.kubernetes.api.model.autoscaling.v2beta2;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;

public class CrossVersionObjectReferenceBuilder extends io.fabric8.kubernetes.api.model.autoscaling.v2beta2.CrossVersionObjectReferenceFluentImpl<io.fabric8.kubernetes.api.model.autoscaling.v2beta2.CrossVersionObjectReferenceBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.kubernetes.api.model.autoscaling.v2beta2.CrossVersionObjectReference,io.fabric8.kubernetes.api.model.autoscaling.v2beta2.CrossVersionObjectReferenceBuilder> {

    io.fabric8.kubernetes.api.model.autoscaling.v2beta2.CrossVersionObjectReferenceFluent<?> fluent;
    Boolean validationEnabled;

    public CrossVersionObjectReferenceBuilder() {
        this(true);
    }

    public CrossVersionObjectReferenceBuilder(Boolean validationEnabled) {
        this(new CrossVersionObjectReference(), validationEnabled);
    }

    public CrossVersionObjectReferenceBuilder(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.CrossVersionObjectReferenceFluent<?> fluent) {
        this(fluent, true);
    }

    public CrossVersionObjectReferenceBuilder(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.CrossVersionObjectReferenceFluent<?> fluent,Boolean validationEnabled) {
        this(fluent, new CrossVersionObjectReference(), validationEnabled);
    }

    public CrossVersionObjectReferenceBuilder(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.CrossVersionObjectReferenceFluent<?> fluent,io.fabric8.kubernetes.api.model.autoscaling.v2beta2.CrossVersionObjectReference instance) {
        this(fluent, instance, true);
    }

    public CrossVersionObjectReferenceBuilder(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.CrossVersionObjectReferenceFluent<?> fluent,io.fabric8.kubernetes.api.model.autoscaling.v2beta2.CrossVersionObjectReference instance,Boolean validationEnabled) {
        this.fluent = fluent; 
        fluent.withApiVersion(instance.getApiVersion()); 
        fluent.withKind(instance.getKind()); 
        fluent.withName(instance.getName()); 
        this.validationEnabled = validationEnabled; 
    }

    public CrossVersionObjectReferenceBuilder(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.CrossVersionObjectReference instance) {
        this(instance,true);
    }

    public CrossVersionObjectReferenceBuilder(io.fabric8.kubernetes.api.model.autoscaling.v2beta2.CrossVersionObjectReference instance,Boolean validationEnabled) {
        this.fluent = this; 
        this.withApiVersion(instance.getApiVersion()); 
        this.withKind(instance.getKind()); 
        this.withName(instance.getName()); 
        this.validationEnabled = validationEnabled; 
    }

    public io.fabric8.kubernetes.api.model.autoscaling.v2beta2.CrossVersionObjectReference build() {
        CrossVersionObjectReference buildable = new CrossVersionObjectReference(fluent.getApiVersion(),fluent.getKind(),fluent.getName());
        return buildable;
    }

    public boolean equals(Object o) {
        if (this == o) return true;
        if (o == null || getClass() != o.getClass()) return false;
        if (!super.equals(o)) return false;
        CrossVersionObjectReferenceBuilder that = (CrossVersionObjectReferenceBuilder) o;
        if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;
        
        if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
        return true;
    }

    public int hashCode() {
        return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
    }

}
